==> haskell-happstack-server-7.8.0.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 happstack-server
version:              7.8.0.2
visibility:           public
id:                   happstack-server-7.8.0.2-9V4gMnXuPaq9IPUI8TBf1N
key:                  happstack-server-7.8.0.2-9V4gMnXuPaq9IPUI8TBf1N
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  ecec85d075705e7d3673c6e930e06b12
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.8.0.2-9V4gMnXuPaq9IPUI8TBf1N
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-wZRRn2HvwH9SmjhvQegiD
    blaze-html-0.9.1.2-B48a7xoEadWCpfVMSvtRUE bytestring-0.10.12.1
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA
    filepath-1.4.2.1 hslogger-1.3.1.0-7oQPnxiMyUEL7kzLplckis
    html-1.0.1.2-BYpT6zvcyak8RR9ba7PA72
    monad-control-1.0.3.1-4fdECBW1lrcHgdlzIumUuS mtl-2.2.2
    network-3.1.3.0-8zUwKO0Sm5f7Rw5zeC6grI
    network-uri-2.6.4.2-EYxdu2yGuicEEj2BOEkBLC
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh parsec-3.1.14.0
    process-1.6.13.2 sendfile-0.7.11.4-BhXtRZAywfiAGx30CJpKNk
    syb-0.7.2.3-E4tH3s3z87qJY1YhFhL5mk
    system-filepath-0.4.14-C2ynfWFOIFw9dM9Eq8zxGZ text-1.2.5.0
    threads-0.5.1.7-7P00BrB2rWo3JqSswIerec time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-37wBEeRGCLdLZYH7gvtRC9
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH unix-2.7.2.2
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f xhtml-3000.2.2.1
    zlib-0.6.3.0-8yAGwyuZ2uAGq492iT1L3K

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-happstack-server-7.8.0.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 happstack-server
version:              7.8.0.2
visibility:           public
id:                   happstack-server-7.8.0.2-GWPRvz7llbm9k3xyNO8nkF
key:                  happstack-server-7.8.0.2-GWPRvz7llbm9k3xyNO8nkF
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  c796f37a65296963d85c99ec1de16f80
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.8.0.2-GWPRvz7llbm9k3xyNO8nkF
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-D7qbdpqh7ZAHvyipCqb2En
    blaze-html-0.9.1.2-4eTAdhXUE0R5xA2sIwi8oW bytestring-0.10.12.1
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA
    filepath-1.4.2.1 hslogger-1.3.1.0-7S0bziVWAWA1CTWZHdkYNd
    html-1.0.1.2-BYpT6zvcyak8RR9ba7PA72
    monad-control-1.0.3.1-35h1aVdsL57202S8tnbNU9 mtl-2.2.2
    network-3.1.3.0-3M5Tdsi477bH0rciWhbCqL
    network-uri-2.6.4.2-18lVeOrHqdkDTTcK9hqBly
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh parsec-3.1.14.0
    process-1.6.13.2 sendfile-0.7.11.4-LjiVmO4qD078USXUHbiFnl
    syb-0.7.2.3-ItYotKJTU3VJfC5cskyLmn
    system-filepath-0.4.14-GHKDuWJRe2MAtGU4oy46w4 text-1.2.5.0
    threads-0.5.1.7-7P00BrB2rWo3JqSswIerec time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-92OnlKVmSzm7Q6K6Tg9Pzs
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH unix-2.7.2.2
    utf8-string-1.0.2-519AraujIYSLY3i7TJuoqO xhtml-3000.2.2.1
    zlib-0.6.3.0-5MlrrAbgjA8AXbUw8xgJze

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
